@@ -70,13 +70,6 @@ class KoCanvasControllerProxyObject;
 class KRITAFLAKE_EXPORT KoCanvasController
 {
 public:
-    /// An enum to alter the positioning and size of the canvas inside the canvas controller
-    enum CanvasMode {
-        AlignTop,     ///< canvas is top aligned if smaller than the viewport
-        Centered,     ///< canvas is centered if smaller than the viewport
-        Infinite,     ///< canvas is never smaller than the viewport
-        Spreadsheet   ///< same as Infinite, but supports right-to-left layouts
-    };
 
     // proxy QObject: use this to connect to slots and signals.
     QPointer<KoCanvasControllerProxyObject> proxyObject;
@@ -100,15 +93,6 @@ public:
      */
     virtual void setMargin(int margin);
 
-    /**
-     * Sets the how the canvas behaves if the zoomed document becomes smaller than the viewport.
-     * @param mode the new canvas mode, CanvasMode::Centered is the default value
-     */
-    virtual void setCanvasMode(KoCanvasController::CanvasMode mode);
-
-    /// Returns the current canvas mode
-    virtual KoCanvasController::CanvasMode canvasMode() const;
-
     /**
      * compatibility with QAbstractScrollArea
      */
@@ -119,15 +103,6 @@ public:
      */
     virtual QSize viewportSize() const = 0;
 
-    /**
-     * Set the shadow option -- by default the canvas controller draws
-     * a black shadow around the canvas widget, which you may or may
-     * not want.
-     *
-     * @param drawShadow if true, the shadow is drawn, if false, not
-     */
-    virtual void setDrawShadow(bool drawShadow) = 0;
-
     /**
      * Set the new canvas to be shown as a child
      * Calling this will emit canvasRemoved() if there was a canvas before, and will emit
@@ -286,6 +261,11 @@ public:
      */
     virtual void setScrollBarValue(const QPoint &value) = 0;
 
+    /**
+     * Update the range of scroll bars
+     */
+    virtual void resetScrollBars() = 0;
+
     /**
      * Called when the size of your document in view coordinates (pixels) changes, for instance when zooming.
      *
@@ -470,7 +450,6 @@ public:
 
     void scrollContentsBy(int /*dx*/, int /*dy*/) override {}
     QSize viewportSize() const override { return QSize(); }
-    void setDrawShadow(bool /*drawShadow*/) override {}
     void setCanvas(KoCanvasBase *canvas) override {Q_UNUSED(canvas)}
     KoCanvasBase *canvas() const override {return 0;}
     int visibleHeight() const override {return 0;}
@@ -493,11 +472,11 @@ public:
     void panRight() override {}
     QPoint scrollBarValue() const override {return QPoint();}
     void setScrollBarValue(const QPoint &/*value*/) override {}
+    void resetScrollBars() override {}
     void updateDocumentSize(const QSize &/*sz*/, bool /*recalculateCenter*/) override {}
     void setZoomWithWheel(bool /*zoom*/) override {}
     void setVastScrolling(qreal /*factor*/) override {}
     QPointF currentCursorPosition() const override { return QPointF(); }
-
 };
 
 #endif
