@@ -26,6 +26,7 @@
 #include <QVector>
 #include <QDomElement>
 #include <QLocale>
+#include <QColor>
 
 #include <klocalizedstring.h>
 
@@ -110,6 +111,26 @@ namespace KisDomUtils {
     }
 
 
+    inline QString qColorToQString(QColor color)
+    {
+        // color channels will usually have 0-255
+        QString customColor = QString::number(color.red()).append(",")
+                             .append(QString::number(color.green())).append(",")
+                             .append(QString::number(color.blue())).append(",")
+                             .append(QString::number(color.alpha()));
+
+        return customColor;
+    }
+
+    inline QColor qStringToQColor(QString colorString)
+    {
+        QStringList colorComponents = colorString.split(',');
+        return QColor(colorComponents[0].toInt(), colorComponents[1].toInt(), colorComponents[2].toInt(), colorComponents[3].toInt());
+    }
+
+
+
+
 /**
  * Save a value of type QRect into an XML tree. A child for \p parent
  * is created and assigned a tag \p tag.  The corresponding value can
