@@ -407,6 +407,12 @@ public:
     void uploadLodDataStruct(LodDataStruct *dst);
     QRegion regionForLodSyncing() const;
 
+    void updateLodDataManager(KisDataManager *srcDataManager,
+                              KisDataManager *dstDataManager, const QPoint &srcOffset, const QPoint &dstOffset,
+                              const QRect &originalRect, int lod);
+
+    void generateLodCloneDevice(KisPaintDeviceSP dst, const QRect &originalRect, int lod);
+
     void tesingFetchLodDevice(KisPaintDeviceSP targetDevice);
 
 
@@ -685,15 +691,13 @@ KisPaintDevice::LodDataStruct* KisPaintDevice::Private::createLodDataStruct(int
     return lodStruct;
 }
 
-void KisPaintDevice::Private::updateLodDataStruct(LodDataStruct *_dst, const QRect &originalRect)
+void KisPaintDevice::Private::updateLodDataManager(KisDataManager *srcDataManager,
+                                                   KisDataManager *dstDataManager,
+                                                   const QPoint &srcOffset,
+                                                   const QPoint &dstOffset,
+                                                   const QRect &originalRect,
+                                                   int lod)
 {
-    LodDataStructImpl *dst = dynamic_cast<LodDataStructImpl*>(_dst);
-    KIS_SAFE_ASSERT_RECOVER_RETURN(dst);
-
-    Data *lodData = dst->lodData.data();
-    Data *srcData = currentNonLodData();
-
-    const int lod = lodData->levelOfDetail();
     const int srcStepSize = 1 << lod;
 
     KIS_ASSERT_RECOVER_RETURN(lod > 0);
@@ -704,7 +708,7 @@ void KisPaintDevice::Private::updateLodDataStruct(LodDataStruct *_dst, const QRe
 
     KIS_ASSERT_RECOVER_NOOP(srcRect.width() / srcStepSize == dstRect.width());
 
-    const int pixelSize = srcData->dataManager()->pixelSize();
+    const int pixelSize = srcDataManager->pixelSize();
 
     int rowsAccumulated = 0;
     int columnsAccumulated = 0;
@@ -733,8 +737,8 @@ void KisPaintDevice::Private::updateLodDataStruct(LodDataStruct *_dst, const QRe
         weights[srcCellSize - 1] = averageWeight - extraWeight;
     }
 
-    InternalSequentialConstIterator srcIntIt(StrategyPolicy(currentStrategy(), srcData->dataManager().data(), srcData->x(), srcData->y()), srcRect);
-    InternalSequentialIterator dstIntIt(StrategyPolicy(currentStrategy(), lodData->dataManager().data(), lodData->x(), lodData->y()), dstRect);
+    InternalSequentialConstIterator srcIntIt(StrategyPolicy(currentStrategy(), srcDataManager, srcOffset.x(), srcOffset.y()), srcRect);
+    InternalSequentialIterator dstIntIt(StrategyPolicy(currentStrategy(), dstDataManager, dstOffset.x(), dstOffset.y()), dstRect);
 
     int rowsRemaining = srcRect.height();
     while (rowsRemaining > 0) {
@@ -782,6 +786,33 @@ void KisPaintDevice::Private::updateLodDataStruct(LodDataStruct *_dst, const QRe
     }
 }
 
+void KisPaintDevice::Private::updateLodDataStruct(LodDataStruct *_dst, const QRect &originalRect)
+{
+    LodDataStructImpl *dst = dynamic_cast<LodDataStructImpl*>(_dst);
+    KIS_SAFE_ASSERT_RECOVER_RETURN(dst);
+
+    Data *lodData = dst->lodData.data();
+    Data *srcData = currentNonLodData();
+
+    const int lod = lodData->levelOfDetail();
+
+    updateLodDataManager(srcData->dataManager().data(), lodData->dataManager().data(),
+                         QPoint(srcData->x(), srcData->y()),
+                         QPoint(lodData->x(), lodData->y()),
+                         originalRect, lod);
+}
+
+void KisPaintDevice::Private::generateLodCloneDevice(KisPaintDeviceSP dst, const QRect &originalRect, int lod)
+{
+    KIS_SAFE_ASSERT_RECOVER_RETURN(fastBitBltPossible(dst));
+
+    Data *srcData = currentNonLodData();
+    updateLodDataManager(srcData->dataManager().data(), dst->dataManager().data(),
+                         QPoint(srcData->x(), srcData->y()),
+                         QPoint(dst->x(), dst->y()),
+                         originalRect, lod);
+}
+
 void KisPaintDevice::Private::uploadLodDataStruct(LodDataStruct *_dst)
 {
     LodDataStructImpl *dst = dynamic_cast<LodDataStructImpl*>(_dst);
@@ -908,7 +939,7 @@ KUndo2Command* KisPaintDevice::Private::convertColorSpace(const KoColorSpace * d
 
     KUndo2Command *parentCommand = new DeviceChangeColorSpaceCommand(q);
 
-    QList<Data*> dataObjects = allDataObjects();;
+    QList<Data*> dataObjects = allDataObjects();
 
     Q_FOREACH (Data *data, dataObjects) {
         if (!data) continue;
@@ -935,7 +966,7 @@ bool KisPaintDevice::Private::assignProfile(const KoColorProfile * profile)
         KoColorSpaceRegistry::instance()->colorSpace(colorSpace()->colorModelId().id(), colorSpace()->colorDepthId().id(), profile);
     if (!dstColorSpace) return false;
 
-    QList<Data*> dataObjects = allDataObjects();;
+    QList<Data*> dataObjects = allDataObjects();
     Q_FOREACH (Data *data, dataObjects) {
         if (!data) continue;
         data->assignColorSpace(dstColorSpace);
@@ -948,7 +979,7 @@ bool KisPaintDevice::Private::assignProfile(const KoColorProfile * profile)
 
 void KisPaintDevice::Private::init(const KoColorSpace *cs, const quint8 *defaultPixel)
 {
-    QList<Data*> dataObjects = allDataObjects();;
+    QList<Data*> dataObjects = allDataObjects();
     Q_FOREACH (Data *data, dataObjects) {
         if (!data) continue;
 
@@ -2027,6 +2058,11 @@ void KisPaintDevice::uploadLodDataStruct(LodDataStruct *dst)
     m_d->uploadLodDataStruct(dst);
 }
 
+void KisPaintDevice::generateLodCloneDevice(KisPaintDeviceSP dst, const QRect &originalRect, int lod)
+{
+    m_d->generateLodCloneDevice(dst, originalRect, lod);
+}
+
 
 KisPaintDeviceFramesInterface* KisPaintDevice::framesInterface()
 {
