@@ -45,6 +45,12 @@ struct KisRasterKeyframe : public KisKeyframe
         return toQShared(new KisRasterKeyframe(this, channel));
     }
 
+    bool hasContent() const override {
+        KisRasterKeyframeChannel *channel = dynamic_cast<KisRasterKeyframeChannel*>(this->channel());
+        KIS_SAFE_ASSERT_RECOVER_RETURN_VALUE(channel, true);
+
+        return channel->keyframeHasContent(this);
+    }
 };
 
 struct KisRasterKeyframeChannel::Private
@@ -83,8 +89,13 @@ KisRasterKeyframeChannel::~KisRasterKeyframeChannel()
 
 int KisRasterKeyframeChannel::frameId(KisKeyframeSP keyframe) const
 {
-    KisRasterKeyframe *key = dynamic_cast<KisRasterKeyframe*>(keyframe.data());
-    Q_ASSERT(key != 0);
+    return frameId(keyframe.data());
+}
+
+int KisRasterKeyframeChannel::frameId(const KisKeyframe *keyframe) const
+{
+    const KisRasterKeyframe *key = dynamic_cast<const KisRasterKeyframe*>(keyframe);
+    KIS_SAFE_ASSERT_RECOVER_RETURN_VALUE(key, -1);
     return key->frameId;
 }
 
@@ -280,6 +291,11 @@ KisKeyframeSP KisRasterKeyframeChannel::loadKeyframe(const QDomElement &keyframe
     return keyframe;
 }
 
+bool KisRasterKeyframeChannel::keyframeHasContent(const KisKeyframe *keyframe) const
+{
+    return !m_d->paintDevice->framesInterface()->frameBounds(frameId(keyframe)).isEmpty();
+}
+
 bool KisRasterKeyframeChannel::hasScalarValue() const
 {
     return false;
