@@ -23,6 +23,7 @@
 
 #include "kis_layer_style_filter.h"
 #include <kritaimage_export.h>
+#include "kis_cached_paint_device.h"
 
 struct psd_layer_effects_overlay_base;
 
@@ -59,6 +60,7 @@ private:
 
 private:
     Mode m_mode;
+    mutable KisCachedPaintDevice m_cachedDevices;
 };
 
 #endif
