@@ -445,6 +445,8 @@ Q_SIGNALS:
 
     void sigCompleteBackgroundSaving(const KritaUtils::ExportFileJob &job, KisImportExportFilter::ConversionStatus status, const QString &errorMessage);
 
+    void sigReferenceImagesChanged();
+
 private Q_SLOTS:
     void finishExportInBackground();
     void slotChildCompletedSavingInBackground(KisImportExportFilter::ConversionStatus status, const QString &errorMessage);
@@ -501,9 +503,6 @@ private:
      */
     bool openFile();
 
-    /** @internal */
-    void setModified();
-
 public:
 
     bool isAutosaving() const override;
@@ -605,6 +604,11 @@ public:
 
     bool save(bool showWarnings, KisPropertiesConfigurationSP exportConfiguration);
 
+    /**
+     * Return the bounding box of the image and associated elements (e.g. reference images)
+     */
+    QRectF documentBounds() const;
+
 Q_SIGNALS:
 
     void completed();
