@@ -19,6 +19,7 @@
 #include "kis_canvas_controller.h"
 
 #include <QMouseEvent>
+#include <QScrollBar>
 #include <QTabletEvent>
 
 #include <klocalizedstring.h>
@@ -28,6 +29,7 @@
 #include "kis_coordinates_converter.h"
 #include "kis_canvas2.h"
 #include "opengl/kis_opengl_canvas2.h"
+#include "KisDocument.h"
 #include "kis_image.h"
 #include "KisViewManager.h"
 #include "KisView.h"
@@ -352,3 +354,46 @@ void KisCanvasController::restoreCanvasState(const KisPropertiesConfiguration &c
     slotToggleWrapAroundMode(config.getBool("wrapAround", false));
     kritaCanvas->setLodAllowedInCanvas(config.getBool("enableInstantPreview", false));
 }
+
+void KisCanvasController::resetScrollBars()
+{
+    // The scrollbar value always points at the top-left corner of the
+    // bit of image we paint.
+
+    KisDocument *doc = m_d->view->document();
+    if (!doc) return;
+
+    QRectF documentBounds = doc->documentBounds();
+    QRectF viewRect = m_d->coordinatesConverter->imageToWidget(documentBounds);
+
+    // Cancel out any existing pan
+    const QRectF imageBounds = m_d->view->image()->bounds();
+    const QRectF imageBB = m_d->coordinatesConverter->imageToWidget(imageBounds);
+    QPointF pan = imageBB.topLeft();
+    viewRect.translate(-pan);
+
+    int drawH = viewport()->height();
+    int drawW = viewport()->width();
+
+    qreal horizontalReserve = vastScrollingFactor() * drawW;
+    qreal verticalReserve = vastScrollingFactor() * drawH;
+
+    qreal xMin = viewRect.left() - horizontalReserve;
+    qreal yMin = viewRect.top() - verticalReserve;
+
+    qreal xMax = viewRect.right() - drawW + horizontalReserve;
+    qreal yMax = viewRect.bottom() - drawH + verticalReserve;
+
+    QScrollBar *hScroll = horizontalScrollBar();
+    QScrollBar *vScroll = verticalScrollBar();
+
+    hScroll->setRange(static_cast<int>(xMin), static_cast<int>(xMax));
+    vScroll->setRange(static_cast<int>(yMin), static_cast<int>(yMax));
+
+    int fontHeight = QFontMetrics(font()).height();
+
+    vScroll->setPageStep(drawH);
+    vScroll->setSingleStep(fontHeight);
+    hScroll->setPageStep(drawW);
+    hScroll->setSingleStep(fontHeight);
+}
