@@ -91,7 +91,6 @@
 #include "kis_action_manager.h"
 #include "operations/kis_operation_configuration.h"
 //new
-#include "kis_recorded_path_paint_action.h"
 #include "kis_node_query_path.h"
 #include "kis_tool_shape.h"
 
@@ -158,7 +157,7 @@ void KisSelectionManager::setup(KisActionManager* actionManager)
     m_reselect = actionManager->createAction("reselect");
     connect(m_reselect, SIGNAL(triggered()), this, SLOT(reselect()));
 
-    m_invert = actionManager->createAction("invert");
+    m_invert = actionManager->createAction("invert_selection");
     m_invert->setOperationID("invertselection");
 
     actionManager->registerOperation(new KisInvertSelectionOperation);
