@@ -37,10 +37,10 @@ KisMetaData::Value exivValueToKMDValue(const Exiv2::Value::AutoPtr value, bool f
     case Exiv2::invalidTypeId:
     case Exiv2::lastTypeId:
     case Exiv2::directory:
-        dbgFile << "Invalid value :" << value->typeId() << " value =" << value->toString().c_str();
+        dbgMetaData << "Invalid value :" << value->typeId() << " value =" << value->toString().c_str();
         return KisMetaData::Value();
     case Exiv2::undefined: {
-        dbgFile << "Undefined value :" << value->typeId() << " value =" << value->toString().c_str();
+        dbgMetaData << "Undefined value :" << value->typeId() << " value =" << value->toString().c_str();
         QByteArray array(value->count() , 0);
         value->copy((Exiv2::byte*)array.data(), Exiv2::invalidByteOrder);
         return KisMetaData::Value(QString(array.toBase64()));
@@ -66,15 +66,15 @@ KisMetaData::Value exivValueToKMDValue(const Exiv2::Value::AutoPtr value, bool f
     case Exiv2::unsignedRational:
         if(value->size() < 2)
         {
-          dbgFile << "Invalid size :" << value->size() << " value =" << value->toString().c_str();
-          return KisMetaData::Value();
+            dbgMetaData << "Invalid size :" << value->size() << " value =" << value->toString().c_str();
+            return KisMetaData::Value();
         }
         return KisMetaData::Value(KisMetaData::Rational(value->toRational().first , value->toRational().second));
     case Exiv2::signedRational:
         if(value->size() < 2)
         {
-          dbgFile << "Invalid size :" << value->size() << " value =" << value->toString().c_str();
-          return KisMetaData::Value();
+            dbgMetaData << "Invalid size :" << value->size() << " value =" << value->toString().c_str();
+            return KisMetaData::Value();
         }
         return KisMetaData::Value(KisMetaData::Rational(value->toRational().first , value->toRational().second));
     case Exiv2::date:
@@ -86,12 +86,12 @@ KisMetaData::Value exivValueToKMDValue(const Exiv2::Value::AutoPtr value, bool f
     case Exiv2::xmpSeq:
     case Exiv2::langAlt:
     default: {
-        dbgFile << "Unknown type id :" << value->typeId() << " value =" << value->toString().c_str();
+        dbgMetaData << "Unknown type id :" << value->typeId() << " value =" << value->toString().c_str();
         //Q_ASSERT(false); // This point must never be reached !
         return KisMetaData::Value();
     }
     }
-    dbgFile << "Unknown type id :" << value->typeId() << " value =" << value->toString().c_str();
+    dbgMetaData << "Unknown type id :" << value->typeId() << " value =" << value->toString().c_str();
     //Q_ASSERT(false); // This point must never be reached !
     return KisMetaData::Value();
 }
@@ -133,7 +133,7 @@ Exiv2::Value* variantToExivValue(const QVariant& variant, Exiv2::TypeId type)
     case Exiv2::comment:
         return new Exiv2::CommentValue(qPrintable(variant.toString()));
     default:
-        dbgFile << "Unhandled type:" << type;
+        dbgMetaData << "Unhandled type:" << type;
         //Q_ASSERT(false);
         return 0;
     }
@@ -166,7 +166,9 @@ Exiv2::Value* kmdValueToExivValue(const KisMetaData::Value& value, Exiv2::TypeId
             return new Exiv2::ValueType<Exiv2::URational>(Exiv2::URational(value.asRational().numerator, value.asRational().denominator));
         }
     case KisMetaData::Value::OrderedArray:
+        /* Falls through */
     case KisMetaData::Value::UnorderedArray:
+        /* Falls through */
     case KisMetaData::Value::AlternativeArray: {
         switch (type) {
         case Exiv2::unsignedByte:
@@ -187,13 +189,15 @@ Exiv2::Value* kmdValueToExivValue(const KisMetaData::Value& value, Exiv2::TypeId
             }
             return ev;
         }
+            break;
         default:
-            dbgFile << type << " " << value;
+            dbgMetaData << type << " " << value;
             //Q_ASSERT(false);
         }
+        /* Falls through */
     }
     default:
-        dbgFile << type << " " << value;
+        dbgMetaData << type << " " << value;
         //Q_ASSERT(false);
     }
     return 0;
@@ -255,7 +259,7 @@ Exiv2::Value* kmdValueToExivXmpValue(const KisMetaData::Value& value)
         Exiv2::Value* arrV = new Exiv2::LangAltValue;
         QMap<QString, KisMetaData::Value> langArray = value.asLangArray();
         for (QMap<QString, KisMetaData::Value>::iterator it = langArray.begin();
-                it != langArray.end(); ++it) {
+             it != langArray.end(); ++it) {
             QString exivVal;
             if (it.key() != "x-default") {
                 exivVal = "lang=" + it.key() + ' ';
