@@ -61,6 +61,8 @@
 #include <kis_canvas2.h>
 #include <kis_cubic_curve.h>
 #include "kis_display_color_converter.h"
+#include <KisDocument.h>
+#include <KisReferenceImagesLayer.h>
 
 #include "kis_config.h"
 #include "kis_config_notifier.h"
@@ -68,7 +70,6 @@
 #include "widgets/kis_cmb_composite.h"
 #include "widgets/kis_slider_spin_box.h"
 #include "kis_canvas_resource_provider.h"
-#include <recorder/kis_recorded_paint_action.h>
 #include "kis_tool_utils.h"
 #include <brushengine/kis_paintop.h>
 #include <brushengine/kis_paintop_preset.h>
@@ -78,7 +79,7 @@
 #include <kis_canvas_resource_provider.h>
 
 
-KisToolPaint::KisToolPaint(KoCanvasBase * canvas, const QCursor & cursor)
+KisToolPaint::KisToolPaint(KoCanvasBase *canvas, const QCursor &cursor)
     : KisTool(canvas, cursor),
       m_showColorPreview(false),
       m_colorPreviewShowComparePlate(false),
@@ -105,7 +106,7 @@ KisToolPaint::KisToolPaint(KoCanvasBase * canvas, const QCursor & cursor)
         m_standardBrushSizes.push_back(maxSize);
     }
 
-    KisCanvas2 * kiscanvas = dynamic_cast<KisCanvas2*>(canvas);
+    KisCanvas2 *kiscanvas = dynamic_cast<KisCanvas2*>(canvas);
     KisActionManager *actionManager = kiscanvas->viewManager()->actionManager();
 
     // XXX: Perhaps a better place for these?
@@ -302,11 +303,15 @@ void KisToolPaint::activateAlternateAction(AlternateAction action)
 {
     switch (action) {
     case PickFgNode:
+        /* Falls through */
     case PickBgNode:
+        /* Falls through */
     case PickFgImage:
+        /* Falls through */
     case PickBgImage:
         delayedAction = action;
         m_colorPickerDelayTimer.start(100);
+        /* Falls through */
     default:
         pickColorWasOverridden();
         KisTool::activateAlternateAction(action);
@@ -337,7 +342,6 @@ void KisToolPaint::activatePickColorDelayed()
     };
 
     repaintDecorations();
-
 }
 
 bool KisToolPaint::isPickingAction(AlternateAction action) {
@@ -375,11 +379,30 @@ void KisToolPaint::addPickerJob(const PickingJob &pickingJob)
     const bool fromCurrentNode = pickingJob.action == PickFgNode || pickingJob.action == PickBgNode;
     m_pickingResource = colorPreviewResourceId(pickingJob.action);
 
+    if (!fromCurrentNode) {
+        auto *kisCanvas = dynamic_cast<KisCanvas2*>(canvas());
+        KIS_SAFE_ASSERT_RECOVER_RETURN(kisCanvas);
+        KisSharedPtr<KisReferenceImagesLayer> referencesLayer = kisCanvas->imageView()->document()->referenceImagesLayer();
+        if (referencesLayer) {
+            QColor color = referencesLayer->getPixel(imagePoint);
+            if (color.isValid() && color.alpha() != 0) {
+                slotColorPickingFinished(KoColor(color, image()->colorSpace()));
+                return;
+            }
+        }
+    }
+
     KisPaintDeviceSP device = fromCurrentNode ?
         currentNode()->colorPickSourceDevice() : image()->projection();
 
+    // Used for color picker blending.
+    KoColor currentColor = canvas()->resourceManager()->foregroundColor();
+    if( pickingJob.action == PickBgNode || pickingJob.action == PickBgImage ){
+        currentColor = canvas()->resourceManager()->backgroundColor();
+    }
+
     image()->addJob(m_pickerStrokeId,
-                    new KisColorPickerStrokeStrategy::Data(device, imagePoint));
+                    new KisColorPickerStrokeStrategy::Data(device, imagePoint, currentColor));
 }
 
 void KisToolPaint::beginAlternateAction(KoPointerEvent *event, AlternateAction action)
@@ -475,10 +498,10 @@ void KisToolPaint::mouseReleaseEvent(KoPointerEvent *event)
 
 QWidget * KisToolPaint::createOptionWidget()
 {
-    QWidget * optionWidget = new QWidget();
+    QWidget *optionWidget = new QWidget();
     optionWidget->setObjectName(toolId());
 
-    QVBoxLayout* verticalLayout = new QVBoxLayout(optionWidget);
+    QVBoxLayout *verticalLayout = new QVBoxLayout(optionWidget);
     verticalLayout->setObjectName("KisToolPaint::OptionWidget::VerticalLayout");
     verticalLayout->setContentsMargins(0,0,0,0);
     verticalLayout->setSpacing(5);
@@ -498,10 +521,10 @@ QWidget * KisToolPaint::createOptionWidget()
     m_optionsWidgetLayout->setSpacing(5);
 
     if (!quickHelp().isEmpty()) {
-        QPushButton* push = new QPushButton(KisIconUtils::loadIcon("help-contents"), QString(), optionWidget);
+        QPushButton *push = new QPushButton(KisIconUtils::loadIcon("help-contents"), QString(), optionWidget);
         connect(push, SIGNAL(clicked()), this, SLOT(slotPopupQuickHelp()));
 
-        QHBoxLayout* hLayout = new QHBoxLayout(optionWidget);
+        QHBoxLayout *hLayout = new QHBoxLayout(optionWidget);
         hLayout->addWidget(push);
         hLayout->addItem(new QSpacerItem(0, 0, QSizePolicy::Expanding, QSizePolicy::Fixed));
         verticalLayout->addLayout(hLayout);
@@ -596,16 +619,6 @@ void KisToolPaint::slotPopupQuickHelp()
     QWhatsThis::showText(QCursor::pos(), quickHelp());
 }
 
-void KisToolPaint::setupPaintAction(KisRecordedPaintAction* action)
-{
-    KisTool::setupPaintAction(action);
-    action->setOpacity(m_opacity / qreal(255.0));
-    const KoCompositeOp* op = compositeOp();
-    if (op) {
-        action->setCompositeOp(op->id());
-    }
-}
-
 KisToolPaint::NodePaintAbility KisToolPaint::nodePaintAbility()
 {
     KisNodeSP node = currentNode();
@@ -697,28 +710,29 @@ void KisToolPaint::requestUpdateOutline(const QPointF &outlineDocPoint, const Ko
 
     KisConfig cfg;
     KisPaintOpSettings::OutlineMode outlineMode;
-    outlineMode = KisPaintOpSettings::CursorNoOutline;
 
     if (isOutlineEnabled() &&
         (mode() == KisTool::GESTURE_MODE ||
          ((cfg.newOutlineStyle() == OUTLINE_FULL ||
            cfg.newOutlineStyle() == OUTLINE_CIRCLE ||
-           cfg.newOutlineStyle() == OUTLINE_TILT ||
-           cfg.newOutlineStyle() == OUTLINE_COLOR ) &&
+           cfg.newOutlineStyle() == OUTLINE_TILT) &&
           ((mode() == HOVER_MODE) ||
            (mode() == PAINT_MODE && cfg.showOutlineWhilePainting()))))) { // lisp forever!
 
-        if(cfg.newOutlineStyle() == OUTLINE_CIRCLE) {
-            outlineMode = KisPaintOpSettings::CursorIsCircleOutline;
+        outlineMode.isVisible = true;
+
+        if (cfg.newOutlineStyle() == OUTLINE_CIRCLE) {
+            outlineMode.forceCircle = true;
         } else if(cfg.newOutlineStyle() == OUTLINE_TILT) {
-            outlineMode = KisPaintOpSettings::CursorTiltOutline;
-        } else if(cfg.newOutlineStyle() == OUTLINE_COLOR) {
-            outlineMode = KisPaintOpSettings::CursorColorOutline;
+            outlineMode.forceCircle = true;
+            outlineMode.showTiltDecoration = true;
         } else {
-            outlineMode = KisPaintOpSettings::CursorIsOutline;
+            // noop
         }
     }
 
+    outlineMode.forceFullSize = cfg.forceAlwaysFullSizedOutline();
+
     m_outlineDocPoint = outlineDocPoint;
     m_currentOutline = getOutlinePath(m_outlineDocPoint, event, outlineMode);
 
