@@ -67,7 +67,7 @@ private Q_SLOTS:
     void entrySelectedBack(KoColorSetEntry entry);
     void setColorSet(KoColorSet* colorSet);
 
-    void setColorFromNameList();
+    void setColorFromNameList(int index);
 
     void saveToWorkspace(KisWorkspaceResource* workspace);
     void loadFromWorkspace(KisWorkspaceResource* workspace);
