@@ -20,13 +20,18 @@
 #include "kis_kra_load_visitor.h"
 #include "kis_kra_tags.h"
 #include "flake/kis_shape_layer.h"
+#include "flake/KisReferenceImagesLayer.h"
+#include "KisReferenceImage.h"
+#include <KisImportExportManager.h>
 
 #include <QRect>
 #include <QBuffer>
 #include <QByteArray>
+#include <QMessageBox>
 
 #include <KoColorSpaceRegistry.h>
 #include <KoColorProfile.h>
+#include <KoFileDialog.h>
 #include <KoStore.h>
 #include <KoColorSpace.h>
 
@@ -128,7 +133,40 @@ bool KisKraLoadVisitor::visit(KisExternalLayer * layer)
 {
     bool result = false;
 
-    if (KisShapeLayer* shapeLayer = dynamic_cast<KisShapeLayer*>(layer)) {
+    if (auto *referencesLayer = dynamic_cast<KisReferenceImagesLayer*>(layer)) {
+        Q_FOREACH(KoShape *shape, referencesLayer->shapes()) {
+            auto *reference = dynamic_cast<KisReferenceImage*>(shape);
+            KIS_SAFE_ASSERT_RECOVER_RETURN_VALUE(reference, false);
+
+            while (!reference->loadImage(m_store)) {
+                if (reference->embed()) {
+                    m_errorMessages << i18n("Could not load embedded reference image %1 ", reference->internalFile());
+                    break;
+                } else {
+                    QString msg = i18nc(
+                        "@info",
+                        "A reference image linked to an external file could not be loaded.\n\n"
+                        "Path: %1\n\n"
+                        "Do you want to select another location?", reference->filename());
+
+                    int locateManually = QMessageBox::warning(0, i18nc("@title:window", "File not found"), msg, QMessageBox::Yes | QMessageBox::No, QMessageBox::Yes);
+
+                    QString url;
+                    if (locateManually == QMessageBox::Yes) {
+                        KoFileDialog dialog(0, KoFileDialog::OpenFile, "OpenDocument");
+                        dialog.setMimeTypeFilters(KisImportExportManager::supportedMimeTypes(KisImportExportManager::Import));
+                        url = dialog.filename();
+                    }
+
+                    if (url.isEmpty()) {
+                        break;
+                    } else {
+                        reference->setFilename(url);
+                    }
+                }
+            }
+        }
+    } else if (KisShapeLayer *shapeLayer = dynamic_cast<KisShapeLayer*>(layer)) {
 
         if (!loadMetaData(layer)) {
             return false;
@@ -469,6 +507,21 @@ bool KisKraLoadVisitor::loadPaintDevice(KisPaintDeviceSP device, const QString&
 template<class DevicePolicy>
 bool KisKraLoadVisitor::loadPaintDeviceFrame(KisPaintDeviceSP device, const QString &location, DevicePolicy policy)
 {
+    {
+        const int pixelSize = device->colorSpace()->pixelSize();
+        KoColor color(Qt::transparent, device->colorSpace());
+
+        if (m_store->open(location + ".defaultpixel")) {
+            if (m_store->size() == pixelSize) {
+                m_store->read((char*)color.data(), pixelSize);
+            }
+
+            m_store->close();
+        }
+
+        policy.setDefaultPixel(device, color);
+    }
+
     if (m_store->open(location)) {
         if (!policy.read(device, m_store->device())) {
             m_warningMessages << i18n("Could not read pixel data: %1.", location);
@@ -481,15 +534,6 @@ bool KisKraLoadVisitor::loadPaintDeviceFrame(KisPaintDeviceSP device, const QStr
         m_warningMessages << i18n("Could not load pixel data: %1.", location);
         return true;
     }
-    if (m_store->open(location + ".defaultpixel")) {
-        int pixelSize = device->colorSpace()->pixelSize();
-        if (m_store->size() == pixelSize) {
-            KoColor color(Qt::transparent, device->colorSpace());
-            m_store->read((char*)color.data(), pixelSize);
-            policy.setDefaultPixel(device, color);
-        }
-        m_store->close();
-    }
 
     return true;
 }
@@ -572,6 +616,13 @@ bool KisKraLoadVisitor::loadMetaData(KisNode* node)
 
 bool KisKraLoadVisitor::loadSelection(const QString& location, KisSelectionSP dstSelection)
 {
+    // by default the selection is expected to be fully transparent
+    {
+        KisPixelSelectionSP pixelSelection = dstSelection->pixelSelection();
+        KoColor transparent(Qt::transparent, pixelSelection->colorSpace());
+        pixelSelection->setDefaultPixel(transparent);
+    }
+
     // Pixel selection
     bool result = true;
     QString pixelSelectionLocation = location + DOT_PIXEL_SELECTION;
