@@ -68,6 +68,8 @@
 #include "KisResourceServerProvider.h"
 #include "kis_keyframe_channel.h"
 #include <kis_filter_configuration.h>
+#include "KisReferenceImagesLayer.h"
+#include "KisReferenceImage.h"
 
 #include "KisDocument.h"
 #include "kis_config.h"
@@ -204,6 +206,7 @@ KisImageSP KisKraLoader::loadXML(const KoXmlElement& element)
     QString colorspacename;
     const KoColorSpace * cs;
 
+
     if ((attr = element.attribute(MIME)) == NATIVE_MIMETYPE) {
 
         if ((m_d->imageName = element.attribute(NAME)).isNull()) {
@@ -304,6 +307,7 @@ KisImageSP KisKraLoader::loadXML(const KoXmlElement& element)
         KoXmlNode child;
         for (child = element.lastChild(); !child.isNull(); child = child.previousSibling()) {
             KoXmlElement e = child.toElement();
+
             if(e.tagName() == CANVASPROJECTIONCOLOR) {
                 if (e.hasAttribute(COLORBYTEDATA)) {
                     QByteArray colorData = QByteArray::fromBase64(e.attribute(COLORBYTEDATA).toLatin1());
@@ -312,6 +316,15 @@ KisImageSP KisKraLoader::loadXML(const KoXmlElement& element)
                 }
             }
 
+
+            if(e.tagName() == GLOBALASSISTANTSCOLOR) {
+                if (e.hasAttribute(SIMPLECOLORDATA)) {
+                    QString colorData = e.attribute(SIMPLECOLORDATA);
+                    m_d->document->setAssistantsGlobalColor(KisDomUtils::qStringToQColor(colorData));
+                }
+            }
+
+
             if(e.tagName()== PROOFINGWARNINGCOLOR) {
                 QDomDocument dom;
                 KoXml::asQDomElement(dom, e);
@@ -501,6 +514,8 @@ void KisKraLoader::loadAssistants(KoStore *store, const QString &uri, bool exter
     QString location;
     QMap<int ,KisPaintingAssistantHandleSP> handleMap;
     KisPaintingAssistant* assistant = 0;
+    const QColor globalColor = m_d->document->assistantsGlobalColor();
+
     QMap<QString,QString>::const_iterator loadedAssistant = m_d->assistantsFilenames.constBegin();
     while (loadedAssistant != m_d->assistantsFilenames.constEnd()){
         const KisPaintingAssistantFactory* factory = KisPaintingAssistantFactoryRegistry::instance()->get(loadedAssistant.value());
@@ -510,6 +525,7 @@ void KisKraLoader::loadAssistants(KoStore *store, const QString &uri, bool exter
             location += m_d->imageName + ASSISTANTS_PATH;
             file_path = location + loadedAssistant.key();
             assistant->loadXml(store, handleMap, file_path);
+            assistant->setAssistantGlobalColorCache(globalColor);
 
             //If an assistant has too few handles than it should according to it's own setup, just don't load it//
             if (assistant->handles().size()==assistant->numHandles()){
@@ -557,7 +573,7 @@ KisNodeSP KisKraLoader::loadNodes(const KoXmlElement& element, KisImageSP image,
 
             if (node.nodeName().toUpper() == LAYERS.toUpper() || node.nodeName().toUpper() == MASKS.toUpper()) {
                 for (child = node.lastChild(); !child.isNull(); child = child.previousSibling()) {
-                    KisNodeSP node = loadNode(child.toElement(), image, parent);
+                    KisNodeSP node = loadNode(child.toElement(), image);
                     if (node) {
                         image->nextLayerName(); // Make sure the nameserver is current with the number of nodes.
                         image->addNode(node, parent);
@@ -573,7 +589,7 @@ KisNodeSP KisKraLoader::loadNodes(const KoXmlElement& element, KisImageSP image,
     return parent;
 }
 
-KisNodeSP KisKraLoader::loadNode(const KoXmlElement& element, KisImageSP image, KisNodeSP parent)
+KisNodeSP KisKraLoader::loadNode(const KoXmlElement& element, KisImageSP image)
 {
     // Nota bene: If you add new properties to layers, you should
     // ALWAYS define a default value in case the property is not
@@ -657,18 +673,19 @@ KisNodeSP KisKraLoader::loadNode(const KoXmlElement& element, KisImageSP image,
     else if (nodeType == CLONE_LAYER)
         node = loadCloneLayer(element, image, name, colorSpace, opacity);
     else if (nodeType == FILTER_MASK)
-        node = loadFilterMask(element, parent);
+        node = loadFilterMask(element);
     else if (nodeType == TRANSFORM_MASK)
-        node = loadTransformMask(element, parent);
+        node = loadTransformMask(element);
     else if (nodeType == TRANSPARENCY_MASK)
-        node = loadTransparencyMask(element, parent);
+        node = loadTransparencyMask(element);
     else if (nodeType == SELECTION_MASK)
-        node = loadSelectionMask(image, element, parent);
+        node = loadSelectionMask(image, element);
     else if (nodeType == COLORIZE_MASK)
-        node = loadColorizeMask(image, element, parent, colorSpace);
-    else if (nodeType == FILE_LAYER) {
+        node = loadColorizeMask(image, element, colorSpace);
+    else if (nodeType == FILE_LAYER)
         node = loadFileLayer(element, image, name, opacity);
-    }
+    else if (nodeType == REFERENCE_IMAGES_LAYER)
+        node = loadReferenceImagesLayer(element, image);
     else {
         m_d->warningMessages << i18n("Layer %1 has an unsupported type: %2.", name, nodeType);
         return 0;
@@ -802,7 +819,7 @@ KisNodeSP KisKraLoader::loadFileLayer(const KoXmlElement& element, KisImageSP im
         if (result == QMessageBox::Yes) {
 
             KoFileDialog dialog(0, KoFileDialog::OpenFile, "OpenDocument");
-            dialog.setMimeTypeFilters(KisImportExportManager::mimeFilter(KisImportExportManager::Import));
+            dialog.setMimeTypeFilters(KisImportExportManager::supportedMimeTypes(KisImportExportManager::Import));
             dialog.setDefaultDir(basePath);
             QString url = dialog.filename();
 
@@ -949,14 +966,14 @@ KisNodeSP KisKraLoader::loadCloneLayer(const KoXmlElement& element, KisImageSP i
 
     KisCloneLayerSP layer = new KisCloneLayer(0, image, name, opacity);
 
-    KisCloneInfo info;
+    KisNodeUuidInfo info;
     if (! (element.attribute(CLONE_FROM_UUID)).isNull()) {
-        info = KisCloneInfo(QUuid(element.attribute(CLONE_FROM_UUID)));
+        info = KisNodeUuidInfo(QUuid(element.attribute(CLONE_FROM_UUID)));
     } else {
         if ((element.attribute(CLONE_FROM)).isNull()) {
             return 0;
         } else {
-            info = KisCloneInfo(element.attribute(CLONE_FROM));
+            info = KisNodeUuidInfo(element.attribute(CLONE_FROM));
         }
     }
     layer->setCopyFromInfo(info);
@@ -971,9 +988,8 @@ KisNodeSP KisKraLoader::loadCloneLayer(const KoXmlElement& element, KisImageSP i
 }
 
 
-KisNodeSP KisKraLoader::loadFilterMask(const KoXmlElement& element, KisNodeSP parent)
+KisNodeSP KisKraLoader::loadFilterMask(const KoXmlElement& element)
 {
-    Q_UNUSED(parent);
     QString attr;
     KisFilterMask* mask;
     QString filtername;
@@ -1002,10 +1018,9 @@ KisNodeSP KisKraLoader::loadFilterMask(const KoXmlElement& element, KisNodeSP pa
     return mask;
 }
 
-KisNodeSP KisKraLoader::loadTransformMask(const KoXmlElement& element, KisNodeSP parent)
+KisNodeSP KisKraLoader::loadTransformMask(const KoXmlElement& element)
 {
     Q_UNUSED(element);
-    Q_UNUSED(parent);
 
     KisTransformMask* mask;
 
@@ -1019,19 +1034,17 @@ KisNodeSP KisKraLoader::loadTransformMask(const KoXmlElement& element, KisNodeSP
     return mask;
 }
 
-KisNodeSP KisKraLoader::loadTransparencyMask(const KoXmlElement& element, KisNodeSP parent)
+KisNodeSP KisKraLoader::loadTransparencyMask(const KoXmlElement& element)
 {
     Q_UNUSED(element);
-    Q_UNUSED(parent);
     KisTransparencyMask* mask = new KisTransparencyMask();
     Q_CHECK_PTR(mask);
 
     return mask;
 }
 
-KisNodeSP KisKraLoader::loadSelectionMask(KisImageSP image, const KoXmlElement& element, KisNodeSP parent)
+KisNodeSP KisKraLoader::loadSelectionMask(KisImageSP image, const KoXmlElement& element)
 {
-    Q_UNUSED(parent);
     KisSelectionMaskSP mask = new KisSelectionMask(image);
     bool active = element.attribute(ACTIVE, "1") == "0" ? false : true;
     mask->setActive(active);
@@ -1040,9 +1053,8 @@ KisNodeSP KisKraLoader::loadSelectionMask(KisImageSP image, const KoXmlElement&
     return mask;
 }
 
-KisNodeSP KisKraLoader::loadColorizeMask(KisImageSP image, const KoXmlElement& element, KisNodeSP parent, const KoColorSpace *colorSpace)
+KisNodeSP KisKraLoader::loadColorizeMask(KisImageSP image, const KoXmlElement& element, const KoColorSpace *colorSpace)
 {
-    Q_UNUSED(parent);
     KisColorizeMaskSP mask = new KisColorizeMask();
     const bool editKeystrokes = element.attribute(COLORIZE_EDIT_KEYSTROKES, "1") == "0" ? false : true;
     const bool showColoring = element.attribute(COLORIZE_SHOW_COLORING, "1") == "0" ? false : true;
@@ -1180,3 +1192,20 @@ void KisKraLoader::loadAudio(const KoXmlElement& elem, KisImageSP image)
         image->animationInterface()->setAudioVolume(audioVolume);
     }
 }
+
+KisNodeSP KisKraLoader::loadReferenceImagesLayer(const KoXmlElement &elem, KisImageSP image)
+{
+    KisSharedPtr<KisReferenceImagesLayer> layer =
+        new KisReferenceImagesLayer(m_d->document->shapeController(), image);
+
+    m_d->document->setReferenceImagesLayer(layer, false);
+
+    for (QDomElement child = elem.firstChildElement(); !child.isNull(); child = child.nextSiblingElement()) {
+        if (child.nodeName().toLower() == "referenceimage") {
+            auto* reference = KisReferenceImage::fromXml(child);
+            layer->addShape(reference);
+        }
+    }
+
+    return layer;
+}
