@@ -132,12 +132,19 @@ KisPaintOpSettingsSP KisDuplicateOpSettings::clone() const
     return setting;
 }
 
-QPainterPath KisDuplicateOpSettings::brushOutline(const KisPaintInformation &info, OutlineMode mode)
+QPainterPath KisDuplicateOpSettings::brushOutline(const KisPaintInformation &info, const OutlineMode &mode)
 {
     QPainterPath path;
 
+    OutlineMode forcedMode = mode;
+
+    if (!forcedMode.isVisible) {
+        forcedMode.isVisible = true;
+        forcedMode.forceCircle = true;
+    }
+
     // clone tool should always show an outline
-    path = KisBrushBasedPaintOpSettings::brushOutlineImpl(info, mode, 1.0, true);
+    path = KisBrushBasedPaintOpSettings::brushOutlineImpl(info, forcedMode, 1.0);
 
     QPainterPath copy(path);
     QRectF rect2 = copy.boundingRect();
