@@ -55,7 +55,7 @@ public:
      * the tool. See bug 362659
      * @return false
      */
-    bool wantsAutoScroll() const {
+    bool wantsAutoScroll() const override {
         return false;
     }
 
@@ -66,6 +66,7 @@ public Q_SLOTS:
 public Q_SLOTS:
     void requestStrokeEnd() override;
     void requestStrokeCancellation() override;
+    void requestUndoDuringStroke() override;
 
 protected Q_SLOTS:
     void resetCursorStyle() override;
