@@ -30,12 +30,6 @@
 #include <brushengine/kis_paintop_preset.h>
 #include "kis_figure_painting_tool_helper.h"
 
-#include <recorder/kis_action_recorder.h>
-#include <recorder/kis_recorded_path_paint_action.h>
-#include <recorder/kis_node_query_path.h>
-
-
-
 KisToolPolyline::KisToolPolyline(KoCanvasBase * canvas)
         : KisToolPolylineBase(canvas, KisToolPolylineBase::PAINT, KisCursor::load("tool_polyline_cursor.png", 6, 6))
 {
@@ -62,14 +56,6 @@ void KisToolPolyline::finishPolyline(const QVector<QPointF>& points)
 {
     if (!blockUntilOperationsFinished()) return;
 
-    if (image()) {
-        KisRecordedPathPaintAction linePaintAction(KisNodeQueryPath::absolutePath(currentNode()),
-                                                   currentPaintOpPreset(),
-                                                   KisDistanceInitInfo());
-        setupPaintAction(&linePaintAction);
-        linePaintAction.addPolyLine(points.toList());
-        image()->actionRecorder()->addAction(linePaintAction);
-    }
     if (!currentNode()->inherits("KisShapeLayer")) {
         KisFigurePaintingToolHelper helper(kundo2_i18n("Draw Polyline"),
                                            image(),
