@@ -26,11 +26,11 @@
 #include "kis_coordinates_converter.h"
 #include "tool_transform_args.h"
 #include "transform_transaction_properties.h"
-#include "krita_utils.h"
+#include "kis_painting_tweaks.h"
 #include "kis_cursor.h"
 #include "kis_transform_utils.h"
 #include "kis_algebra_2d.h"
-
+#include "KisHandlePainterHelper.h"
 
 struct KisWarpTransformStrategy::Private
 {
@@ -43,8 +43,8 @@ struct KisWarpTransformStrategy::Private
           currentArgs(_currentArgs),
           transaction(_transaction),
           lastNumPoints(0),
-          drawConnectionLines(true),
-          drawOrigPoints(true),
+          drawConnectionLines(false), // useful while developing
+          drawOrigPoints(false),
           drawTransfPoints(true),
           closeOnStartPointClick(false),
           clipOriginalPointsPosition(true),
@@ -209,7 +209,7 @@ void KisWarpTransformStrategy::drawConnectionLines(QPainter &gc,
     QPen antsPen;
     QPen outlinePen;
 
-    KritaUtils::initAntsPen(&antsPen, &outlinePen);
+    KisPaintingTweaks::initAntsPen(&antsPen, &outlinePen);
 
     const int numPoints = origPoints.size();
 
@@ -237,7 +237,6 @@ void KisWarpTransformStrategy::paint(QPainter &gc)
     gc.save();
     gc.setTransform(m_d->handlesTransform, true);
 
-    // draw connecting lines
     if (m_d->drawConnectionLines) {
         gc.setOpacity(0.5);
 
@@ -247,12 +246,15 @@ void KisWarpTransformStrategy::paint(QPainter &gc)
                             m_d->currentArgs.isEditingTransformPoints());
     }
 
+
+    QPen mainPen(Qt::black);
+    QPen outlinePen(Qt::white);
+
     // draw handles
     {
         const int numPoints = m_d->currentArgs.origPoints().size();
 
-        QPen mainPen(Qt::black);
-        QPen outlinePen(Qt::white);
+
 
         qreal handlesExtraScale = KisTransformUtils::scaleFromAffineMatrix(m_d->handlesTransform);
 
@@ -313,6 +315,42 @@ void KisWarpTransformStrategy::paint(QPainter &gc)
         }
 
     }
+
+    // draw grid lines only if we are using the GRID mode.
+    if (m_d->currentArgs.warpCalculation() == KisWarpTransformWorker::WarpCalculation::GRID) {
+
+    // see how many rows we have. we are only going to do lines up to 6 divisions/
+    // it is almost impossible to use with 6 even.
+    const int numPoints = m_d->currentArgs.origPoints().size();
+
+    // grid is always square, so get the square root to find # of rows
+    int rowsInWarp = sqrt(m_d->currentArgs.origPoints().size());
+
+
+        KisHandlePainterHelper handlePainter(&gc);
+        handlePainter.setHandleStyle(KisHandleStyle::primarySelection());
+
+        // draw horizontal lines
+        for (int i = 0; i < numPoints; i++) {
+            if (i != 0 &&  i % rowsInWarp == rowsInWarp -1) {
+                // skip line if it is the last in the row
+            } else {
+                handlePainter.drawConnectionLine(m_d->currentArgs.transfPoints()[i], m_d->currentArgs.transfPoints()[i+1]  );
+            }
+        }
+
+        // draw vertical lines
+        for (int i = 0; i < numPoints; i++) {
+
+            if ( (numPoints - i - 1) < rowsInWarp ) {
+                // last row doesn't need to draw vertical lines
+            } else {
+                handlePainter.drawConnectionLine(m_d->currentArgs.transfPoints()[i], m_d->currentArgs.transfPoints()[i+rowsInWarp] );
+            }
+        }
+
+    } // end if statement
+
     gc.restore();
 }
 
@@ -534,9 +572,10 @@ void KisWarpTransformStrategy::Private::recalculateTransformations()
 {
     QTransform scaleTransform = KisTransformUtils::imageToFlakeTransform(converter);
 
-    QTransform resultTransform = q->thumbToImageTransform() * scaleTransform;
-    qreal scale = KisTransformUtils::scaleFromAffineMatrix(resultTransform);
-    bool useFlakeOptimization = scale < 1.0;
+    QTransform resultThumbTransform = q->thumbToImageTransform() * scaleTransform;
+    qreal scale = KisTransformUtils::scaleFromAffineMatrix(resultThumbTransform);
+    bool useFlakeOptimization = scale < 1.0 &&
+        !KisTransformUtils::thumbnailTooSmall(resultThumbTransform, q->originalImage().rect());
 
     QVector<QPointF> thumbOrigPoints(currentArgs.numPoints());
     QVector<QPointF> thumbTransfPoints(currentArgs.numPoints());
@@ -552,11 +591,11 @@ void KisWarpTransformStrategy::Private::recalculateTransformations()
         QPointF origTLInFlake = imageToThumb(transaction.originalTopLeft(), useFlakeOptimization);
 
         if (useFlakeOptimization) {
-            transformedImage = q->originalImage().transformed(q->thumbToImageTransform() * scaleTransform);
+            transformedImage = q->originalImage().transformed(resultThumbTransform);
             paintingTransform = QTransform();
         } else {
             transformedImage = q->originalImage();
-            paintingTransform = q->thumbToImageTransform() * scaleTransform;
+            paintingTransform = resultThumbTransform;
 
         }
 
@@ -569,7 +608,7 @@ void KisWarpTransformStrategy::Private::recalculateTransformations()
     } else {
         transformedImage = q->originalImage();
         paintingOffset = imageToThumb(transaction.originalTopLeft(), false);
-        paintingTransform = q->thumbToImageTransform() * scaleTransform;
+        paintingTransform = resultThumbTransform;
     }
 
     handlesTransform = scaleTransform;
